@@ -426,6 +426,8 @@ struct synthv1_del
 	float *delay;
 	float *feedb;
 	float *bpm;
+	float *bpmsync, bpmsync0;
+	float *bpmhost;
 };
 
 
@@ -851,7 +853,8 @@ synthv1_voice::synthv1_voice ( synthv1_impl *pImpl ) :
 {
 }
 
-// constructor
+
+// engine constructor
 
 synthv1_impl::synthv1_impl ( uint16_t iChannels, uint32_t iSampleRate )
 {
@@ -884,6 +887,9 @@ synthv1_impl::synthv1_impl ( uint16_t iChannels, uint32_t iSampleRate )
 	// compressors none yet
 	m_comp = 0;
 
+	// no delay sync yet
+	m_del.bpmsync0 = 0.0f;
+
 	// number of channels
 	setChannels(iChannels);
 
@@ -1115,6 +1121,8 @@ void synthv1_impl::setParamPort ( synthv1::ParamIndex index, float *pfParam )
 	case synthv1::DEL1_DELAY:     m_del.delay        = pfParam; break;
 	case synthv1::DEL1_FEEDB:     m_del.feedb        = pfParam; break;
 	case synthv1::DEL1_BPM:       m_del.bpm          = pfParam; break;
+	case synthv1::DEL1_BPMSYNC:   m_del.bpmsync      = pfParam; break;
+	case synthv1::DEL1_BPMHOST:   m_del.bpmhost      = pfParam; break;
 	case synthv1::DYN1_COMPRESS:  m_dyn.compress     = pfParam; break;
 	case synthv1::DYN1_LIMITER:   m_dyn.limiter      = pfParam; break;
 	default: break;
@@ -1237,6 +1245,8 @@ float *synthv1_impl::paramPort ( synthv1::ParamIndex index )
 	case synthv1::DEL1_DELAY:     pfParam = m_del.delay;        break;
 	case synthv1::DEL1_FEEDB:     pfParam = m_del.feedb;        break;
 	case synthv1::DEL1_BPM:       pfParam = m_del.bpm;          break;
+	case synthv1::DEL1_BPMSYNC:   pfParam = m_del.bpmsync;      break;
+	case synthv1::DEL1_BPMHOST:   pfParam = m_del.bpmhost;      break;
 	case synthv1::DYN1_COMPRESS:  pfParam = m_dyn.compress;     break;
 	case synthv1::DYN1_LIMITER:   pfParam = m_dyn.limiter;      break;
 	default: break;
@@ -1947,6 +1957,15 @@ void synthv1_impl::process ( float **ins, float **outs, uint32_t nframes )
 		pv = pv_next;
 	}
 
+	// delay sync toggle
+	if (int(*m_del.bpmsync) != int(m_del.bpmsync0)) {
+		float *del_bpm = m_del.bpm; 
+		float *del_bpmhost = m_del.bpmhost;
+		m_del.bpmsync0 = *m_del.bpmsync;
+		m_del.bpmhost = del_bpm;
+		m_del.bpm = del_bpmhost;
+	}
+
 	// effects
 
 	for (k = 0; k < m_iChannels; ++k) {
