@@ -164,6 +164,8 @@ public:
 		DEL1_DELAY,
 		DEL1_FEEDB,
 		DEL1_BPM,
+		DEL1_BPMSYNC,
+		DEL1_BPMHOST,
 		DYN1_COMPRESS,
 		DYN1_LIMITER,
 
