@@ -21,8 +21,6 @@
 
 #include "synthv1_lv2.h"
 
-#include "synthv1widget_lv2.h"
-
 #include "lv2/lv2plug.in/ns/ext/urid/urid.h"
 #include "lv2/lv2plug.in/ns/ext/midi/midi.h"
 #include "lv2/lv2plug.in/ns/ext/atom/util.h"
@@ -137,6 +135,10 @@ void synthv1_lv2::deactivate (void)
 }
 
 
+//-------------------------------------------------------------------------
+// synthv1_lv2 - LV2 desc.
+//
+
 static LV2_Handle synthv1_lv2_instantiate (
 	const LV2_Descriptor *, double sample_rate, const char *,
 	const LV2_Feature *const *host_features )
@@ -192,42 +194,6 @@ static const void *synthv1_lv2_extension_data ( const char * )
 }
 
 
-static LV2UI_Handle synthv1_lv2ui_instantiate (
-	const LV2UI_Descriptor *, const char *, const char *,
-	LV2UI_Write_Function write_function,
-	LV2UI_Controller controller, LV2UI_Widget *widget,
-	const LV2_Feature *const * )
-{
-	synthv1widget_lv2 *pWidget = new synthv1widget_lv2(controller, write_function);
-	*widget = pWidget;
-	return pWidget;
-}
-
-
-static void synthv1_lv2ui_cleanup ( LV2UI_Handle ui )
-{
-	synthv1widget_lv2 *pWidget = static_cast<synthv1widget_lv2 *> (ui);
-	if (pWidget)
-		delete pWidget;
-}
-
-
-static void synthv1_lv2ui_port_event (
-	LV2UI_Handle ui, uint32_t port_index,
-	uint32_t buffer_size, uint32_t format, const void *buffer )
-{
-	synthv1widget_lv2 *pWidget = static_cast<synthv1widget_lv2 *> (ui);
-	if (pWidget)
-		pWidget->port_event(port_index, buffer_size, format, buffer);
-}
-
-
-static const void *synthv1_lv2ui_extension_data ( const char * )
-{
-	return NULL;
-}
-
-
 static const LV2_Descriptor synthv1_lv2_descriptor =
 {
 	SYNTHV1_LV2_URI,
@@ -240,15 +206,6 @@ static const LV2_Descriptor synthv1_lv2_descriptor =
 	synthv1_lv2_extension_data
 };
 
-static const LV2UI_Descriptor synthv1_lv2ui_descriptor =
-{
-	SYNTHV1_LV2UI_URI,
-	synthv1_lv2ui_instantiate,
-	synthv1_lv2ui_cleanup,
-	synthv1_lv2ui_port_event,
-	synthv1_lv2ui_extension_data
-};
-
 
 LV2_SYMBOL_EXPORT const LV2_Descriptor *lv2_descriptor ( uint32_t index )
 {
@@ -256,10 +213,4 @@ LV2_SYMBOL_EXPORT const LV2_Descriptor *lv2_descriptor ( uint32_t index )
 }
 
 
-LV2_SYMBOL_EXPORT const LV2UI_Descriptor *lv2ui_descriptor ( uint32_t index )
-{
-	return (index == 0 ? &synthv1_lv2ui_descriptor : NULL);
-}
-
-
 // end of synthv1_lv2.cpp
