@@ -127,6 +127,8 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	m_ui.Pha1WetKnob->setSpecialValueText(sOff);
 	m_ui.Del1WetKnob->setSpecialValueText(sOff);
 
+	m_ui.Del1BpmKnob->setSpecialValueText(tr("Auto"));
+
 	// DCO octave limits.
 	m_ui.Dco1OctaveKnob->setMinimum(-4.0f);
 	m_ui.Dco1OctaveKnob->setMaximum(+4.0f);
@@ -644,6 +646,10 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	setParamKnob(synthv1::DEL1_FEEDB, m_ui.Del1FeedbKnob);
 	setParamKnob(synthv1::DEL1_BPM,   m_ui.Del1BpmKnob);
 
+	QObject::connect(m_ui.Del1BpmKnob,
+		SIGNAL(valueChanged(float)),
+		SLOT(bpmSyncChanged()));
+
 	// Dynamics
 	setParamKnob(synthv1::DYN1_COMPRESS, m_ui.Dyn1CompressKnob);
 	setParamKnob(synthv1::DYN1_LIMITER,  m_ui.Dyn1LimiterKnob);
@@ -718,13 +724,28 @@ void synthv1widget::setParamValue ( synthv1::ParamIndex index, float fValue )
 	if (pKnob)
 		pKnob->setValue(fValue);
 
+	updateParamEx(index, fValue);
+
 	--m_iUpdate;
 }
 
 float synthv1widget::paramValue ( synthv1::ParamIndex index ) const
 {
+	float fParamValue = 0.0f;
+
 	synthv1widget_knob *pKnob = paramKnob(index);
-	return (pKnob ? pKnob->value() : 0.0f);
+	if (pKnob) {
+		fParamValue = pKnob->value();
+	} else {
+		synthv1 *pSynth = instance();
+		if (pSynth) {
+			const float *pParamPort = pSynth->paramPort(index);
+			if (pParamPort)
+				fParamValue = *pParamPort;
+		}
+	}
+
+	return fParamValue;
 }
 
 
@@ -736,7 +757,9 @@ void synthv1widget::paramChanged ( float fValue )
 
 	synthv1widget_knob *pKnob = qobject_cast<synthv1widget_knob *> (sender());
 	if (pKnob) {
-		updateParam(m_knobParams.value(pKnob), fValue);
+		synthv1::ParamIndex index = m_knobParams.value(pKnob);
+		updateParam(index, fValue);
+		updateParamEx(index, fValue);
 		m_ui.StatusBar->showMessage(QString("%1 / %2: %3")
 			.arg(m_ui.StackedWidget->currentWidget()->windowTitle())
 			.arg(pKnob->toolTip())
@@ -746,6 +769,24 @@ void synthv1widget::paramChanged ( float fValue )
 }
 
 
+// Update local tied widgets.
+void synthv1widget::updateParamEx ( synthv1::ParamIndex index, float fValue )
+{
+	++m_iUpdate;
+
+	switch (index) {
+	case synthv1::DEL1_BPMSYNC:
+		if (fValue > 0.0f)
+			m_ui.Del1BpmKnob->setValue(0.0f);
+		// Fall thru...
+	default:
+		break;
+	}
+
+	--m_iUpdate;
+}
+
+
 // Reset all param knobs to default values.
 void synthv1widget::resetParams (void)
 {
@@ -1056,4 +1097,27 @@ void synthv1widget::updateDirtyPreset ( bool bDirtyPreset )
 }
 
 
+// Delay BPM change.
+void synthv1widget::bpmSyncChanged (void)
+{
+	if (m_iUpdate > 0)
+		return;
+
+	++m_iUpdate;
+	synthv1 *pSynth = instance();
+	if (pSynth) {
+		float *pBpmSync = pSynth->paramPort(synthv1::DEL1_BPMSYNC);
+		if (pBpmSync) {
+			const bool bBpmSync0
+				= (*pBpmSync > 0.0f);
+			const bool bBpmSync1
+				= (m_ui.Del1BpmKnob->minimum() >= m_ui.Del1BpmKnob->value());
+			if ((bBpmSync1 && !bBpmSync0) || (!bBpmSync1 && bBpmSync0))
+				*pBpmSync = (bBpmSync1 ? 1.0f : 0.0f);
+		}
+	}
+	--m_iUpdate;
+}
+
+
 // end of synthv1widget.cpp
