@@ -22,17 +22,7 @@
 #ifndef __synthv1widget_config_h
 #define __synthv1widget_config_h
 
-#include "config.h"
-
-#define SYNTHV1_TITLE	PACKAGE_NAME
-#define SYNTHV1_VERSION	PACKAGE_VERSION
-
-#define SYNTHV1_SUBTITLE     "an old-school polyphonic synthesizer."
-#define SYNTHV1_WEBSITE      "http://synthv1.sourceforge.net"
-#define SYNTHV1_COPYRIGHT    "Copyright (C) 2012-2013, rncbc aka Rui Nuno Capela. All rights reserved."
-
-#define SYNTHV1_DOMAIN	"rncbc.org"
-
+#include "synthv1_config.h"
 
 #include <QSettings>
 #include <QStringList>
